@@ -24,9 +24,31 @@ class BaseAuthenticator(object):
         return True
 
 
+class MetaAnonimous(type):
+    def __str__(mcs):
+        return "Anonimous access"
+
+
+class MetaByKey(type):
+    def __str__(mcs):
+        return "Authorization by key"
+
+
+class MetaByLogin(type):
+    def __str__(mcs):
+        return "Authorization by login and password"
+
+
+class MetaBySession(type):
+    def __str__(mcs):
+        return "Authorization by session"
+
+
 class AnonimousAuthenticator(BaseAuthenticator):
     """ Always return true.
     """
+    __metaclass__ = MetaAnonimous
+
     def get_identifier(self):
         return self.resource.request.META.get('REMOTE_ADDR', 'anonymous')
 
@@ -52,6 +74,8 @@ class UserAuthenticator(BaseAuthenticator):
     username_fieldname = 'username'
     password_fieldname = 'password'
 
+    __metaclass__ = MetaByLogin
+
     def authenticate(self):
         request = self.resource.request
         try:
@@ -67,6 +91,8 @@ class UserAuthenticator(BaseAuthenticator):
 class UserLoggedInAuthenticator(BaseAuthenticator):
     """ Use Djagno's built-in request session for authentication.
     """
+    __metaclass__ = MetaBySession
+
     def authenticate(self):
         request = self.resource.request
         if getattr(request, 'user', None) and request.user.is_active:
@@ -75,7 +101,6 @@ class UserLoggedInAuthenticator(BaseAuthenticator):
                 self.identifier = request.user.username
         return self.get_identifier()
 
-
 try:
     from adrest.models import AccessKey
     from django.core.exceptions import ObjectDoesNotExist
@@ -84,6 +109,7 @@ try:
     class AccessKeyAuthenticator(BaseAuthenticator):
         """ Use AccessKey identification.
         """
+        __metaclass__ = MetaByKey
 
         def authenticate(self):
             """ Authenticate user using AccessKey from HTTP Header or GET params.
